#!/bin/sh
#
# Plugin for wminfo, shows:
#   1. (Optional) Weather Info from NOOA created from a 90 minute cron job
#      from https://tgftp.nws.noaa.gov/data/forecasts/zone/$freg/$fzone
#      where $freg is your area and $zone is your region
#      see: https://tgftp.nws.noaa.gov/data/forecasts/zone
#   2. wlan0 status -- right now specific to Linux and some OpenBSD hosts
#   3. tun0 status  -- right now specific to Linux and some OpenBSD hosts
#   4. (Optional) Reminder
#   5. (Optional) fortune zippy - you want wminfo to scroll this
#
# To use I excute this:
#      wminfo -s 1 -k -r 18 -u 29 -p ~/.fvwm/cde/bin/wminfo_plug.sh -b rgb:ae/b2/c3 -f black &
# -b color from fvwm2rc
#

set -o pipefail

#
#  f_obsd_interface()
#
f_obsd_interface()
{
    l_intf="$1"
    l_st=""

    /sbin/ifconfig ${l_intf} > /dev/null 2>&1
    if [ "$?" -ne "0" ]; then
	return 1
    fi

    /sbin/ifconfig ${l_intf} 2> /dev/null | grep 'status' | grep active > /dev/null 2>&1

    if [ "$?" -eq "0" ]; then
	return 0
    else
	return 1
    fi


} # END f_obsd_interface()

#
#  f_obsd_net()
#
f_obsd_net()
{
    if [ "$HOST" = "" ]; then
	export HOST=`uname -n | awk -F '.' '{print $1}'`
    fi

    case "$HOST" in
	"obsd2")
	    l_net=iwn0
	    ;;
	"hairball")
	    l_net=ath0
	    ;;
	*)
	    l_net="none"
	    ;;
    esac

    let g_num_lines=g_num_lines+1
    if [ "$l_net" = "none" ]; then
	echo "$HOST not supported"
    else
	f_obsd_interface $l_net
	if [ "$?" -eq "0" ]; then
	    echo "$l_net UP"
	else
	    echo "$l_net DWN"
	fi
    fi

    let g_num_lines=g_num_lines+1
    f_obsd_interface tun0
    if [ "$?" -eq "0" ]; then
	echo "tun0 UP"
    else
	echo "tun0 DWN"
    fi

} # END: f_obsd_net()

#------------------------------------------------------------------------------
# f_show_remind() -- show reminder from ~/.jmc_reminder
#------------------------------------------------------------------------------
f_show_remind()
{
    l_showl="$1"
    l_lines=""

    if [ ! -x $HOME/bin/Util/show_reminder.sh ]; then
	let g_num_lines=g_num_lines+1
	echo "               "
	return
    fi

    l_lines="`$HOME/bin/Util/show_reminder.sh miniB | head -n 1`"

    let g_num_lines=g_num_lines+1
    if [ "$l_lines" = "" ]; then
	echo "               "
    else
	echo "$l_lines"
    fi

    return
    
} # END: f_show_remind()

#------------------------------------------------------------------------------
# f_show_weather() -- print fortune/zippy
#------------------------------------------------------------------------------
f_show_weather()
{

    if [ -r /var/local/jmc_dat/noaa/out/out.degrees.fmt1 ]; then
	cat /var/local/jmc_dat/noaa/out/out.degrees.fmt1 | sed 's/[()]//g'
	let g_num_lines=g_num_lines+1
    fi

} # f_show_weather()

#------------------------------------------------------------------------------
# f_show_fortune() -- print fortune/zippy
#------------------------------------------------------------------------------
f_show_fortune()
{
    l_sr_line=""
    l_file_fortune="$tdir/wminfo_fortune_line.$USER"
    l_file_counter="$tdir/wminfo_fortune_cycle.$USER"
    l_count="0"

    type fortune > /dev/null 2>&1
    if [ "$?" -ne "0" ]; then
	return
    fi

    let g_num_lines=g_num_lines+1

    if [ ! -f "$l_file_counter" ]; then
	echo "$l_count" > "$l_file_counter"
	fortune -s zippy | tr '\n' ' ' | cut -c 1-1000 | sed 's/^/ !     /' > "$l_file_fortune"
    else
	l_count=`cat $l_file_counter`
    fi
    if [ "$l_count" -gt "$g_cycle_fortune" ]; then
	echo "0" > "$l_file_counter"
	fortune -s zippy | tr '\n' ' ' | cut -c 1-1000 | sed 's/^/ !     /' > "$l_file_fortune"
    else
	let l_count=l_count+1
	echo "$l_count" > "$l_file_counter"
    fi
    cat $l_file_fortune

} # END: f_show_fortune()

#------------------------------------------------------------------------------
# f_net_eth0_linux() -- show eth0 info
#------------------------------------------------------------------------------
f_net_eth0_linux()
{
    l_eth0=/sys/class/net/eth0/operstate
    
    if [ -f "$l_eth0" ]; then
	case "`cat $l_eth0`" in
	    "up")
		let g_num_lines=g_num_lines+1
		echo "eth0 UP"
		;;
	    *)
		let g_num_lines=g_num_lines+1
		echo "eth0 DWN"
		;;
	esac
    else
	let g_num_lines=g_num_lines+1
	echo "eth0 DWN"
    fi
    
} # f_net_eth0_linux()

#------------------------------------------------------------------------------
# f_net_wlan0_linux() -- show wlan0 info
#------------------------------------------------------------------------------
f_net_wlan0_linux()
{

    l_wlan0=/sys/class/net/wlan0/operstate

    if test -f "$l_wlan0"
    then
	case "`cat $l_wlan0`" in
	    "up")
		let g_num_lines=g_num_lines+1
		echo "wlan0 UP"
		;;
	    *)
		let g_num_lines=g_num_lines+1
		echo "wlan0 DWN"
		;;
	esac
    else
	let g_num_lines=g_num_lines+1
	echo "wlan0 DWN"
    fi

} # f_net_wlan0_linux()

#------------------------------------------------------------------------------
# f_net_tun0_linux() -- show tun0 info
#------------------------------------------------------------------------------
f_net_tun0_linux()
{
    tun0=/sys/class/net/tun0/operstate

    if [ -f "$tun0" ]; then
	case "`cat $tun0`" in
	    "unknown")
		let g_num_lines=g_num_lines+1
		echo "tun0 UP"
		;;
	    "up")
		let g_num_lines=g_num_lines+1
		echo "tun0 UP"
		;;
	    *)
		let g_num_lines=g_num_lines+1
		echo "tun0 DWN"
		;;
	esac
    else
	let g_num_lines=g_num_lines+1
	echo "tun0 DWN"
    fi

} # END: f_net_tun0_linux()

###############################################################################
# main
###############################################################################
export HTHEME=$HOME/.fvwm/cde
g_dir_data=$HTHEME/data
g_cycle_fortune="12"
g_num_lines="0"

if [ "$OS" = "" ]; then
    export OS="`uname -s`"
fi
if [ "$USER" = "" ]; then
    export USER="`id -un`"
fi

if [ -d "$TMPDIR" ]; then
    tdir="/mnt/tmpfs/wminfo_${USER}"
else
    tdir="$g_dir_data"
fi

if [ ! -d "$tdir" ]; then
    mkdir -p "$tdir"
    chmod 700 "$tdir"
fi
if [ ! -d "$tdir" ]; then
    echo "ERROR COULD"
    echo "NOT CREATE"
    echo "$tdir"
    echo "$0"
    exit 0
fi

f_show_weather

case "$OS" in
    "Linux")
	f_net_wlan0_linux
	f_net_tun0_linux
	;;
    "OpenBSD")
	f_obsd_net
	;;
    *)
	let g_num_lines=g_num_lines+1
	echo "$OS not yet supported"
	;;
esac

f_show_remind
f_show_fortune

case "$g_num_lines" in
    "0")
	echo "               "
	echo "               "
	echo "               "
	echo "               "
	echo "               "
	;;
    "1")
	echo "               "
	echo "               "
	echo "               "
	echo "               "
	;;
    "2")
	echo "               "
	echo "               "
	echo "               "
	;;
    "3")
	echo "               "
	echo "               "
	;;
    "4")
	echo "               "
	;;
esac

exit 0
